@@ -30,10 +30,16 @@
 
 #ifdef IS_HILDON
 #include "pimc-ui.h"
+#if HILDON_VER > 0
+#include <hildon/hildon-file-chooser-dialog.h>
+#include <hildon/hildon-caption.h>
+#include <hildon/hildon-date-editor.h>
+#else
 #include <hildon-fm/hildon-widgets/hildon-file-chooser-dialog.h>
 #include <hildon-widgets/hildon-caption.h>
 #include <hildon-widgets/hildon-date-editor.h>
 #include <hildon-widgets/hildon-input-mode-hint.h>
+#endif /* HILDON_VER */
 #endif
 
 void on_edit_cancel_clicked (GtkButton * button, gpointer user_data);
@@ -114,15 +120,30 @@ pop_singles (GtkWidget *vtable, GSList *list, GtkWidget *pw, gboolean visible, g
               || strstr(e->tag,".MOBILE") 
               || strstr(e->tag,".FAX"))
             {
+#ifdef IS_HILDON
+#if HILDON_VER > 0
+	      /* Use Hildon telephone number mode */
+	      hildon_gtk_entry_set_input_mode(GTK_ENTRY(w), (HILDON_GTK_INPUT_MODE_TELE));
+#else
               g_signal_connect (G_OBJECT (w), "insert-text", 
 		         G_CALLBACK (on_phone_insert_text), NULL);
+#endif /* HILDON_VER */
+              g_signal_connect (G_OBJECT (w), "insert-text", 
+		         G_CALLBACK (on_phone_insert_text), NULL);
+#endif /* IS_HILDON */
             }
 #ifdef IS_HILDON
           if (strstr(e->tag,".WEB")
               || strstr(e->tag,".EMAIL")
               || strstr (e->tag, ".WWW"))
             {
-              g_object_set (G_OBJECT (w), HILDON_AUTOCAP, FALSE, NULL);
+#if HILDON_VER > 0
+	      /* Turn off HILDON_GTK_INPUT_MODE_AUTOCAP */
+	      hildon_gtk_entry_set_input_mode(GTK_ENTRY(w), (HILDON_GTK_INPUT_MODE_FULL));
+#else
+  g_object_set (G_OBJECT (w), HILDON_AUTOCAP, FALSE, NULL);
+#endif /* HILDON_VER */
+              
             }
 
           l = hildon_caption_new (size_group, e->name, w, NULL, HILDON_CAPTION_OPTIONAL);
